===============================
Jobber
===============================

.. image:: https://img.shields.io/pypi/v/Jobber.svg
        :target: https://pypi.python.org/pypi/Jobber


"Jobber is a program that executes pipelines. It manages job dependencies, restarts them if necessary and logs their status in a database. Jobs are persisted in a database and survive system crashes."

* Free software: BSD license
* Documentation: https://Jobber.readthedocs.org.
